@@ -710,16 +710,7 @@ liqcell *liqflow_run_create()
 		liqcell_handleradd_withcontext(cmdclear, "click", cmdclear_click, self );
 		liqcell_child_append(  self, cmdclear);
 
-		//############################# txtchecking:label
-		liqcell *txtchecking = liqcell_quickcreatevis("txtchecking", "textbox", 0,400, 720,80);
-		liqcell_setfont(	txtchecking, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (29), 0) );
-		liqcell_setcaption(txtchecking, "abc" );
-		liqcell_propsets(  txtchecking, "textcolor", "rgb(255,255,255)" );
-		liqcell_propsets(  txtchecking, "backcolor", "rgb(64,0,0)" );
-		liqcell_propsets(  txtchecking, "bordercolor", "rgb(200,100,100)" );
-		//liqcell_propseti(  txtchecking, "textalign", 2 );
-		//liqcell_handleradd_withcontext(txtchecking, "click", txtchecking_click, self );
-		liqcell_child_append(  self, txtchecking);
+
 		
 		
 	liqcell_propsets(  cmdclear, "textcolor", "rgb(0,0,0)" );
